import { ReconnectingWebsocketFeed } from './util';
function isFillEventUpdate(obj) {
    return obj.event !== undefined;
}
function isHeadUpdate(obj) {
    return obj.head !== undefined;
}
export class FillsFeed extends ReconnectingWebsocketFeed {
    _subscriptions;
    _onFill = null;
    _onHead = null;
    constructor(url, options) {
        super(url, options?.reconnectionIntervalMs, options?.reconnectionMaxAttempts);
        this._subscriptions = options?.subscriptions;
        this.onMessage((data) => {
            if (isFillEventUpdate(data) && this._onFill) {
                this._onFill(data);
            }
            else if (isHeadUpdate(data) && this._onHead) {
                this._onHead(data);
            }
        });
        if (this._subscriptions !== undefined) {
            this.subscribe(this._subscriptions);
        }
    }
    subscribe(subscriptions) {
        if (this.connected()) {
            this._socket.send(JSON.stringify({
                command: 'subscribe',
                ...subscriptions,
            }));
        }
        else {
            console.warn('[FillsFeed] attempt to subscribe when not connected');
        }
    }
    unsubscribe(marketId) {
        if (this.connected()) {
            this._socket.send(JSON.stringify({
                command: 'unsubscribe',
                marketId,
            }));
        }
        else {
            console.warn('[FillsFeed] attempt to unsubscribe when not connected');
        }
    }
    onFill(callback) {
        this._onFill = callback;
    }
    onHead(callback) {
        this._onHead = callback;
    }
}
