import { ReconnectingWebsocketFeed } from './util';
function isOrderbookL2Update(obj) {
    return obj.update !== undefined;
}
function isOrderbookL2Checkpoint(obj) {
    return obj.bids !== undefined && obj.asks !== undefined;
}
export class OrderbookFeed extends ReconnectingWebsocketFeed {
    _subscriptions;
    _onL2Update = null;
    _onL2Checkpoint = null;
    constructor(url, options) {
        super(url, options?.reconnectionIntervalMs, options?.reconnectionMaxAttempts);
        this._subscriptions = options?.subscriptions;
        this.onMessage((data) => {
            if (isOrderbookL2Update(data) && this._onL2Update) {
                this._onL2Update(data);
            }
            else if (isOrderbookL2Checkpoint(data) && this._onL2Checkpoint) {
                this._onL2Checkpoint(data);
            }
        });
        if (this._subscriptions !== undefined) {
            this.subscribe(this._subscriptions);
        }
    }
    subscribe(subscriptions) {
        if (this.connected()) {
            this._socket.send(JSON.stringify({
                command: 'subscribe',
                ...subscriptions,
            }));
        }
        else {
            console.warn('[OrderbookFeed] attempt to subscribe when not connected');
        }
    }
    unsubscribe(marketId) {
        if (this.connected()) {
            this._socket.send(JSON.stringify({
                command: 'unsubscribe',
                marketId,
            }));
        }
        else {
            console.warn('[OrderbookFeed] attempt to unsubscribe when not connected');
        }
    }
    onL2Update(callback) {
        this._onL2Update = callback;
    }
    onL2Checkpoint(callback) {
        this._onL2Checkpoint = callback;
    }
}
